/* 
Mikroekonometria 
Zajęcia 4 - Regresja liniowa / Budowanie modelu ekonometrycznego 
CC BY: Wiktor Budziński
*/

log using me4
clear all
cls

use me_wine.dta, clear


global vintage Vintage91-Vintage99 Vintage00
global region Napavalley bayareacentral sonoma southcoast carneros sierrafoothills mendocinolake washington 
global variety Nonvarietal Pinotnoir Cabernet Merlot Shyrah 
global type Reserve Vineyard Estate 

// Przeskalujmy zmienna Cases
replace Cases = Cases/100 

// 1.A Zacznij od prostego modelu regresji liniowej
	// Zrobione w poprzednim kodzie 
	
// 1.B Dodaj do modelu efekty nieliniowe

// Tworzymy model uwzględniając nieliniowe transformacje zmiennych (aby analizowana zależność była bardziej liniowa)

// Generujemy nieliniowe przeksztalcenia
gen LogCases = log(Cases)
gen LogScore= log(Score)
gen ScoreSq = Score^2

// Model z logarytmami
reg LogPrice LogCases LogScore i.Age $region $variety $type $vintage
predict reszty3, residuals
estat ovtest // Test RESET na poprawność formy funkcyjnej
twoway scatter reszty3 Cases || qfit reszty3 Cases
twoway scatter reszty3 Score || qfit reszty3 Score

// Model z kwadratem
reg LogPrice LogCases Score ScoreSq i.Age $region $variety $type $vintage
display -_b[Score]/(2*_b[ScoreSq]) // minimum
sum Score
predict reszty4, residuals
estat ovtest // Test RESET na poprawność formy funkcyjnej
twoway scatter reszty4 Score || qfit reszty4 Score

// Czy wplyw age jest faktycznie nieliniowy
test 2.Age = 3.Age - 2.Age = 4.Age - 3.Age = 5.Age - 4.Age = 6.Age - 5.Age
reg LogPrice LogCases Score ScoreSq Age $region $variety $type $vintage
estat ovtest // Test RESET na poprawność formy funkcyjnej

// Mozna probowac znalezc lepsze formy funkcyjne rozkodowujac zmienne na poziomy

egen Cases_group = cut(Cases), group(10) label // Rozkodowujemy na 10 grup mniej więcej tej samej wielkosci
tabulate Cases_group

egen Score_group = cut(Score), group(10) label // Rozkodowujemy na 10 grup mniej więcej tej samej wielkosci
tabulate Score_group

reg LogPrice i.Cases_group i.Score_group Age $region $variety $type $vintage
estat ovtest // Test RESET na poprawność formy funkcyjnej

help coefplot
// ado uninstall gr0059_1
coefplot, drop(_cons Age $region $variety $type Vintage91 Vintage92 Vintage93 Vintage94  Vintage95 Vintage96 Vintage97 Vintage98 Vintage99)

// Alternatywnie mozna probowac rozdzielic zmienna po rownych interwalach
/*
egen Cases_group2 = cut(Cases), at(0,130, 260, 390, 520, 650, 780, 910, 1040, 1170, 1301) label // Rozkodowujemy na 10 grup mniej więcej tej samej wielkosci
tabulate Cases_group2

egen Score_group2 = cut(Score), at(68,71, 74, 77, 80, 83, 86, 89, 92, 95, 100) label // Rozkodowujemy na 10 grup mniej więcej tej samej wielkosci
tabulate Score_group2

reg LogPrice i.Cases_group2 i.Score_group2 Age $region $variety $type $vintage
estat ovtest // Test RESET na poprawność formy funkcyjnej
coefplot, drop(_cons Age $region $variety $type Vintage91 Vintage92 Vintage93 Vintage94 Vintage95 Vintage96 Vintage97 Vintage98 Vintage99) */

// Model ze Score do 3 potegi
gen ScoreTh = Score^3
reg LogPrice LogCases Score ScoreSq ScoreTh Age $region $variety $type $vintage

// 1.C Dodaj do modelu interakcje między wybranymi zmiennymi

gen Variety = 1*Nonvarietal+2*Pinotnoir+3*Cabernet+4*Merlot + 5*Shyrah
reg LogPrice LogCases c.LogCases#i.Variety Score c.Score#i.Variety ScoreSq Age c.Age#i.Variety $region $variety $type $vintage

// ZADANIE: Dodaj interakcje zmiennych LogCases, Score i Age ze zmienna washington
	// Sprawdz czy poprawia to forme funkcyjna


	reg LogPrice LogCases c.LogCases#i.Variety Score c.Score#i.Variety c.Score#i.washington ScoreSq Age c.Age#i.Variety $region $variety $type $vintage

	
// 1.D Podsumuj wnioski dotyczące wpływu podaży wina oraz jego oceny na cenę

// Zidentyfikowano nieliniowy zwiazek między ceną wina a jego podażą (liczbą wyprodukowanych skrzynek) 
// Ten związek dobrze opisuje zależność log-log
// Dla win wyprodukowanych w stanie kalifornia, z winogron rodzaju Zinfandel wzrost podaży o 1% powoduje spadek ceny o
display _b[LogCases] // procent
// Dla win wyprodukowanych w stanie waszyngton, z winogron rodzaju Zinfandel wzrost podaży o 1% powoduje spadek ceny o
display _b[LogCases] + _b[c.LogCases#5.Variety] // procent

// Dla oceny wina przez ekspertów, ten związek jest opisany przez zależność log - funkcja kwadratowa
// Dla win wyprodukowanych w stanie kalifornia, z winogron rodzaju Zinfandel obserwujemy, że jeśli ocena jest mniejsza niż
display -(_b[Score])/(2*_b[ScoreSq]) // to wpływa ona negatywnie na cenę
// display -(_b[Score] + _b[c.Score#1.washington])/(2*_b[ScoreSq]) // to wpływa ona negatywnie na cenę
// W przeciwnym wypadku mamy pozytywny wpływ

// Dla oceny 
scalar ScoreVal = 86
// mozemy powiedziec, ze wzrost oceny o jednostke zmieni cene o 
display 100*(_b[Score]+2*_b[ScoreSq]*ScoreVal) // procent
// bardziej dokladnie
display 100*(exp(_b[Score]+2*_b[ScoreSq]*ScoreVal) - 1) // procent
display 100*(exp(_b[Score]+2*_b[ScoreSq]*ScoreVal + _b[c.Score#1.washington]) - 1) // procent


log close